@@ -12,7 +12,7 @@
 
 package Pod::Parser;
 
-$VERSION = 1.03;   ## Current version of this package
+$VERSION = 1.04;   ## Current version of this package
 require  5.003;    ## requires Perl version 5.003 or later
 
 #############################################################################
@@ -29,7 +29,7 @@ Pod::Parser - base class for creating POD filters and translators
     @ISA = qw(Pod::Parser);
 
     sub command { 
-        my ($parser, $command, $paragraph, $attributes) = @_;
+        my ($parser, $command, $paragraph) = @_;
         ## Interpret the command and its text; sample actions might be:
         if ($command eq 'head1') { ... }
         elsif ($command eq 'head2') { ... }
@@ -55,7 +55,7 @@ Pod::Parser - base class for creating POD filters and translators
     }
 
     sub interior_sequence { 
-        my ($parser, $seq_command, $seq_argument, $attributes) = @_;
+        my ($parser, $seq_command, $seq_argument) = @_;
         ## Expand an interior sequence; sample actions might be:
         return "*$seq_argument*"     if ($seq_command = 'B');
         return "`$seq_argument'"     if ($seq_command = 'C');
@@ -73,7 +73,7 @@ Pod::Parser - base class for creating POD filters and translators
 
 =head1 REQUIRES
 
-perl5.003, Exporter, FileHandle, Carp
+perl5.003, Pod::InputObjects, Exporter, FileHandle, Carp
 
 =head1 EXPORTS
 
@@ -151,6 +151,7 @@ how to intepret the commands and translate the result.
 use vars qw($VERSION @ISA);
 use strict;
 #use diagnostics;
+use Pod::InputObjects;
 use Carp;
 use Exporter;
 use FileHandle;
@@ -169,30 +170,17 @@ want to override. These methods are as follows:
 
 =head1 B<command()>
 
-            $parser->command($cmd,$text,$attrs);
-
+            $parser->command($cmd,$text,$pod_para);
 
 This method should be overridden by subclasses to take the appropriate
 action when a POD command paragraph (denoted by a line beginning with
 "=") is encountered. When such a POD directive is seen in the input,
 this method is called and is passed the command name C<$cmd>, and the
 remainder of the text paragraph C<$text>, which appears immediately after
-the command name. The C<$attrs> argument is a reference to a hash-table
-(associative array) which indicates some attributes or properties of
-the command. Currently supported attributed supported are:
-
-=over 4
-
-=item C<-prefix>
-
-The command-prefix used (which should be the string "=").
-
-=item C<-separator>
-
-The string of characters which separated the command from its corresponding
-text.
-
-=back
+the command name. The C<$pod_para> argument is a reference to a 
+C<Pod::Paragraph> object which contains further information about the
+paragraph command. Please see L<Pod::InputObjects> for details if
+you need to access this additional information.
 
 B<Note> that this method I<is> called for C<=pod> paragraphs.
 
@@ -203,14 +191,9 @@ method with the command paragraph).
 =cut
 
 sub command {
-    my ($self, $cmd, $text, $attrs)  = @_;
-    ## Use sensible defaults if any arguments are undefined
-    $cmd  = ''  unless (defined $cmd);
-    $text = ''  unless (defined $text);
-    my $pfx  = (exists $attrs->{-prefix}) ? $attrs->{-prefix} : '=';
-    my $sep  = (exists $attrs->{-separator}) ? $attrs->{-separator} : ' ';
+    my ($self, $cmd, $text, $pod_para)  = @_;
     ## Just treat this like a textblock
-    $self->textblock("${pfx}${cmd}${sep}${text}");
+    $self->textblock($pod_para->raw_text());
 }
 
 ##---------------------------------------------------------------------------
@@ -267,7 +250,7 @@ sub textblock {
 
 =head1 B<interior_sequence()>
 
-            $parser->interior_sequence($seq_cmd,$seq_arg,$attrs);
+            $parser->interior_sequence($seq_cmd,$seq_arg,$pod_seq);
 
 
 This method should be overridden by subclasses to take the appropriate
@@ -279,21 +262,10 @@ passed the sequence command C<$seq_cmd> and the corresponding text
 C<$seq_arg>. It is invoked by the B<interpolate()> method for each interior
 sequence that occurs in the string that it is passed. It should return
 the desired text string to be used in place of the interior sequence.
-The C<$attrs> argument is a reference to a hash-table (associative array)
-which indicates some attributes or properties of the interior sequence.
-Currently supported attributes supported are:
-
-=over 4
-
-=item C<-ldelim>
-
-The leftmost delimiter beginning the C<$seq_arg> (should be "<").
-
-=item C<-rdelim>
-
-The rightmost delimiter ending the C<$seq_arg> (should be ">").
-
-=back
+The C<$pod_seq> argument is a reference to a C<Pod::InteriorSequence>
+object which contains further information about the interior sequence.
+Please see L<Pod::InputObjects> for details if you need to access this
+additional information.
 
 Subclass implementations of this method may wish to invoke the the
 B<sequence_commands()> method to examine the set of interior sequence
@@ -308,11 +280,9 @@ the input) to the caller.
 =cut
 
 sub interior_sequence {
-    my ($self, $seq_cmd, $seq_arg, $attrs) = @_;
-    ## Use sensible defaults if any arguments are undefined
-    my $ldelim  = (exists $attrs->{-ldelim}) ? $attrs->{-ldelim} : '<';
-    my $rdelim  = (exists $attrs->{-rdelim}) ? $attrs->{-rdelim} : '>';
-    return  "${seq_cmd}${ldelim}${seq_arg}${rdelim}";
+    my ($self, $seq_cmd, $seq_arg, $pod_seq) = @_;
+    ## Just return the raw text of the interior sequence
+    return  $pod_seq->raw_text();
 }
 
 #############################################################################
@@ -329,8 +299,7 @@ be overridden, but it may be useful for subclasses to take advantage of them.
 
 =head1 B<new()>
 
-            Pod::Parser->new();
-
+            my $parser = Pod::Parser->new();
 
 This is the constructor for B<Pod::Parser> and its subclasses. You
 I<do not> need to override this method! It is capable of constructing
@@ -607,9 +576,6 @@ sub parse_paragraph {
     local $_;
 
     ## This is the end of a non-empty paragraph
-    ++$input_top->{-paragraphs};  ## update file paragraph count
-    ++$self->{_PARAGRAPHS};        ## update total paragraph count
-
     ## Ignore up until next POD directive if we are cutting
     if ($self->{_CUTTING}) {
        return  unless ($text =~ /^=/);
@@ -637,7 +603,8 @@ sub parse_paragraph {
     return 1  if ((! defined $text) || ($text eq "") || ($self->{_CUTTING}));
 
     ## Look for one of the three types of paragraphs
-    my ($pfx, $cmd, $arg, $sep, $attrs) = ('', '', '', '', {});
+    my ($pfx, $cmd, $arg, $sep) = ('', '', '', '');
+    my $pod_para = undef;
     if ($text =~ /^={1,2}(?=\S)/) {
         ## Looks like a command paragraph. Capture the command prefix used
         ## ("=" or "=="), as well as the command-name, its paragraph text,
@@ -651,18 +618,24 @@ sub parse_paragraph {
            return;
         }
         ## Save the attributes indicating how the command was specified.
-        $attrs = { -prefix => $pfx, -separator => $sep };
+        $pod_para = new Pod::Paragraph(
+              -name      => $cmd,
+              -text      => $text,
+              -prefix    => $pfx,
+              -separator => $sep
+        );
     }
+    $pod_para = new Pod::Paragraph(-text => $text)  unless (defined $pod_para);
     # ## Invoke appropriate callbacks
     # if (exists $self->{_CALLBACKS}) {
     #    ## Look through the callback list, invoke callbacks,
     #    ## then see if we need to do the default actions
     #    ## (invoke_callbacks will return true if we do).
-    #    return  1  unless $self->invoke_callbacks($cmd, $text, $attrs);
+    #    return  1  unless $self->invoke_callbacks($cmd, $text, $pod_para);
     # }
     if ($cmd ne '') {
         ## A command paragraph
-        $self->command($cmd, $text, $attrs);
+        $self->command($cmd, $text, $pod_para);
     }
     elsif ($text =~ /^\s+/) {
         ## Indented text - must be a verbatim paragraph
@@ -718,14 +691,10 @@ sub parse_from_filehandle {
     ## Put this stream at the top of the stack and do beginning-of-input
     ## processing. NOTE that $in_fh might be reset during this process.
     my $input_top = $self->_push_input_stream($in_fh, $out_fh);
-    $in_fh = $self->{_INPUT};
 
     my $textline  = '';
     my $paragraph = '';
-    while ($textline = $in_fh->getline()) {
-        ++$input_top->{-lines};  ## Count lines for this file
-        ++$self->{_LINES};       ## Count total lines
-
+    while ($textline = $input_top->getline()) {
         $textline = $self->preprocess_line($textline);
         next  unless ((defined $textline)  &&  ($textline ne ''));
 
@@ -981,23 +950,6 @@ sub total_lines {
 
 ##---------------------------------------------------------------------------
 
-=head1 B<total_paragraphs()>
-
-            $numpara = $parser->total_paragraphs();
-
-
-The total number of input paragraphs read thus far. This includes I<all>
-paragraphs, regardless of whether or not they were part of the POD
-documentation.
-
-=cut
-
-sub total_paragraphs {
-   return $_[0]->{_PARAGRAPHS};
-}
-
-##---------------------------------------------------------------------------
-
 =head1 B<input_streams()>
 
             $listref = $parser->input_streams();
@@ -1015,35 +967,8 @@ being parsed is always at the end (or top) of the input stack. When an
 input stream has been exhausted, it is popped off the end of the
 input stack.
 
-Each element on this input stack is a reference to a hash-table whose
-elements are indexed by the following keys:
-
-=over 4
-
-=item C<-name>
-
-The name of the corresponding input file.
-
-=item C<-handle>
-
-The corresponding input filehandle.
-
-=item C<-lines>
-
-The number of input lines read from the corresponding input stream.
-
-=item C<-paragraphs>
-
-The number of paragraphs read from the corresponding input stream
-(which includes input paragraphs that are I<not> part of the POD
-documentation).
-
-=item C<-was_cutting>
-
-The value of the C<cutting> state (that the B<cutting()> method would
-have returned) immediately before any input was read from this input
-stream. After all input from this stream has been read, the C<cutting>
-state is restored to this value.
+Each element on this input stack is a reference to C<Pod::InputSource>
+object. Please see L<Pod::InputObjects> for more details.
 
 =back
 
@@ -1092,16 +1017,8 @@ processing nested interior sequences.
 
 The current interior sequence command (the one currently being processes)
 should always be at the top of this stack. Each element on this stack
-is a reference to a hash-table whose elements are indexed by the following
-keys:
-
-=over 4
-
-=item C<-name>
-
-The command-name of the corresponding interior sequence.
-
-=back
+is a reference to a C<Pod::InteriorSequence> object. Please see
+L<Pod::InputObjects> for more details.
 
 =cut
 
@@ -1155,9 +1072,9 @@ sub _interpolate_bottom_up {
     local $_;
     my $result = '';
     ## Keep track of a stack of sequences currently "in progress"
-    my $sequence_stack = $self->{_SEQUENCE_CMDS};
+    my $seq_stack = $self->{_SEQUENCE_CMDS};
     my ($seq_cmd, $seq_arg, $end) = ('', '', undef);
-    my ($sequence, $attrs);
+    my $pod_sequence = undef;
     ## Parse all sequences until end-of-string or we match the end-regex
     while (($text ne '')  &&  ($text =~ /([A-Z])<|($end_re)/)) {
         $result .= $`;  ## Append text before the match to the result
@@ -1170,12 +1087,12 @@ sub _interpolate_bottom_up {
             (! defined $end)  and  $end = "";
             ## If the sequence stack is empty, this cant be the end because
             ## we havent yet seen a proper beginning. Keep looking.
-            next if ((@{$sequence_stack} == 0) && ($result .= $end));
+            next if ((@{$seq_stack} == 0) && ($result .= $end));
            
             ## The following is a *hack* to allow '->' and '=>' inside of
             ## C<...> sequences (but not '==>' or '-->')
-            if (($end eq '>') && (@{$sequence_stack} > 0)) {
-                my $top_cmd = $sequence_stack->[$#{$sequence_stack}]->{-name};
+            if (($end eq '>') && (@{$seq_stack} > 0)) {
+                my $top_cmd = $seq_stack->[$#{$seq_stack}]->cmd_name();
                 ## Exit the loop if this was the end of the sequence.
                 last unless (($top_cmd eq 'C') && ($result =~ /[^-=][-=]$/));
                 ## This was a "false-end" that was really '->' or '=>'
@@ -1185,13 +1102,16 @@ sub _interpolate_bottom_up {
         }
         ## At this point we have found an interior sequence,
         ## we need to obtain its argument
-        $sequence = { -name => $seq_cmd };
-        push(@{$sequence_stack}, $sequence);
-        $seq_arg = $self->_interpolate_bottom_up($text, '>');
+        $pod_sequence = new Pod::InteriorSequence(
+                          -name => $seq_cmd,
+                    );
+        push(@{$seq_stack}, $pod_sequence);
+        $seq_arg = $pod_sequence->text(
+                         $self->_interpolate_bottom_up($text, '>')
+                   );
         ## Now process the interior sequence
-        $attrs = { -ldelim => '<', -rdelim => '>' };
-        $result .= $self->interior_sequence($seq_cmd, $seq_arg, $attrs);
-        pop(@{$sequence_stack});
+        $result .= $self->interior_sequence($seq_cmd, $seq_arg, $pod_sequence);
+        pop(@{$seq_stack});
     }
     ## Handle whatever is left if we didnt match the ending regexp
     unless ((defined $end) && ($end_re ne '$')) {
@@ -1245,7 +1165,6 @@ sub _push_input_stream {
     unless (defined  $self->{_TOP_STREAM}) {
         $out_fh  = \*STDOUT  unless (defined $out_fh);
         $self->{_LINES}         = 0;   ## total lines read
-        $self->{_PARAGRAPHS}    = 0;   ## total paragraphs read
         $self->{_CUTTING}       = 1;   ## current "cutting" state
         $self->{_SEQUENCE_CMDS} = [];  ## list of nested interior sequences
         $self->{_INPUT_STREAMS} = [];  ## stack of all input streams
@@ -1258,13 +1177,13 @@ sub _push_input_stream {
     $self->{_INFILE}  = '<unknown>'  unless (defined  $self->{_INFILE});
     $self->{_INPUT}   = $in_fh;
     my $input_stack   = $self->{_INPUT_STREAMS};
-    my $input_top     = $self->{_TOP_STREAM} = {
-            -name        => $self->{_INFILE},
-            -handle      => $in_fh,
-            -lines       => 0,
-            -paragraphs  => 0,
-            -was_cutting => $self->{_CUTTING}
-    };
+    my $input_top     = $self->{_TOP_STREAM}
+                      = new Pod::InputSource(
+                            -name        => $self->{_INFILE},
+                            -handle      => $in_fh,
+                            -lines       => 0,
+                            -was_cutting => $self->{_CUTTING}
+                        );
     push(@{$input_stack}, $input_top);
 
     ## Perform beginning-of-document and/or beginning-of-input processing
@@ -1305,14 +1224,14 @@ sub _pop_input_stream {
     ## Restore cutting state to whatever it was before we started
     ## parsing this file.
     my $old_top = pop(@{$input_stack});
-    $self->{_CUTTING} = $old_top->{-was_cutting};
+    $self->{_CUTTING} = $old_top->was_cutting();
 
     ## Dont to reset the input indicators
     my $input_top = undef;
     if (@{$input_stack} > 0) {
        $input_top = $self->{_TOP_STREAM} = $input_stack->[$#{$input_stack}];
-       $self->{_INFILE}  = $input_top->{-name};
-       $self->{_INPUT}   = $input_top->{-handle};
+       $self->{_INFILE}  = $input_top->name();
+       $self->{_INPUT}   = $input_top->handle();
     } else {
        delete $self->{_TOP_STREAM};
        delete $self->{_INPUT_STREAMS};
@@ -1343,7 +1262,7 @@ causing any namespace clashes due to multiple inheritance.
 
 =head1 AUTHOR
 
-Brad Appleton E<lt>bradapp@enteract.mot.conE<gt>
+Brad Appleton E<lt>bradapp@enteract.mot.comE<gt>
 
 Based on code for B<Pod::Text> written by
 Tom Christiansen E<lt>tchrist@mox.perl.comE<gt>
