@@ -12,7 +12,7 @@
 
 package Pod::PlainText;
 
-$VERSION = 1.03;   ## Current version of this package
+$VERSION = 1.04;   ## Current version of this package
 require  5.003;    ## requires Perl version 5.002 or later
 
 =head1 NAME
@@ -45,6 +45,14 @@ or
        $parser->parse_from_file($_);
     }
 
+=head1 REQUIRES
+
+perl5.003, Pod::Select, Term::Cap, Exporter, Carp
+
+=head1 EXPORTS
+
+pod2plaintext()
+
 =head1 DESCRIPTION
 
 Pod::PlainText is a module that can convert documentation in the POD
@@ -54,8 +62,8 @@ boldface/underline, and can be enabled via C<$Pod::PlainText::termcap=1>.
 If termcap has not been enabled, then backspaces will be used to
 simulate bold and underlined text.
 
-A separate F<pod2plaintext> program is included that is primarily a wrapper for
-C<Pod::PlainText::pod2plaintext()>.
+A separate F<pod2plaintext> program is included that is primarily a wrapper
+for C<Pod::PlainText::pod2plaintext()>.
 
 The single function C<pod2plaintext()> can take one or two arguments. The first
 should be the name of a file to read the pod from, or "<&STDIN" to read from
@@ -71,7 +79,7 @@ L<Pod::Parser>.
 Tom Christiansen E<lt>tchrist@mox.perl.comE<gt>
 
 Modified to derive from B<Pod::Parser> by
-Brad Appleton E<lt>bradapp@enteract.mot.conE<gt>
+Brad Appleton E<lt>bradapp@enteract.mot.comE<gt>
 
 =cut
 
@@ -82,9 +90,9 @@ use strict;
 #use diagnostics;
 use Carp;
 use Exporter;
-use Pod::Parser;
+use Pod::Select;
 use Term::Cap;
-@ISA = qw(Exporter Pod::Parser);
+@ISA = qw(Exporter Pod::Select);
 @EXPORT = qw(&pod2plaintext);
 
 %HTML_Escapes = (
@@ -352,7 +360,7 @@ sub IP_output {
         croak if ($@);
     }
     select((select($out_fh), $~ = $fmt_name)[0]);
-    local($:) = ($self->{HEADINGS}->[0] eq "SYNOPSIS") ? "\n " : $: ;
+    local($:) = ($self->curr_headings(1) eq 'SYNOPSIS') ? "\n " : $: ;
     write $out_fh;
 }
 
@@ -394,7 +402,7 @@ sub output {
             croak if ($@);
         }
         select((select($out_fh), $~ = $fmt_name)[0]);
-        local($:) = ($self->{HEADINGS}->[0] eq "SYNOPSIS") ? "\n " : $: ;
+        local($:) = ($self->curr_headings(1) eq 'SYNOPSIS') ? "\n " : $: ;
         write $out_fh;
     }
     else {
@@ -426,6 +434,7 @@ sub internal_lrefs {
 sub begin_pod {
     my $self = shift;
 
+    $self->{BEGUN} = [];
     $self->{TERMCAP} = 0;
     #$self->{USE_FORMAT} = 1;
 
@@ -462,6 +471,12 @@ sub end_pod {
     $self->item('', '', '')  if (defined $self->{ITEM});
 }
 
+sub begun_excluded {
+    my $self = shift;
+    my @begun = @{ $self->{BEGUN} };
+    return (@begun > 0) ? ($begun[$#begun] ne 'text') : 0;
+}
+
 sub command {
     my $self = shift;
     my $cmd  = shift;
@@ -470,6 +485,7 @@ sub command {
     $_    = ''  unless (defined $_);
     my $out_fh  = $self->output_handle();
 
+    return  if (($cmd ne 'end') and $self->begun_excluded());
     return  $self->item($cmd, $_)  if (defined $self->{ITEM});
     $_ = $self->interpolate($_);
     s/\s*$/\n/;
@@ -500,6 +516,16 @@ sub command {
         }
         $self->{NEEDSPACE} = 1;
     }
+    elsif ($cmd eq 'begin') {
+       my ($kind) = /^(\S*)/;
+       push( @{ $self->{BEGUN} }, $kind );
+    }
+    elsif ($cmd eq 'end') {
+       pop( @{ $self->{BEGUN} } );
+    }
+    elsif ($cmd eq 'for') {
+       $self->textblock($')  if (/^text\b\s*/);
+    }
     elsif ($cmd eq 'item') {
         $self->makespace();
         # s/\A(\s*)\*/$1\xb7/ if $self->{FANCY};
@@ -515,6 +541,7 @@ sub command {
 sub verbatim {
     my $self = shift;
     local $_ = shift;
+    return  if $self->begun_excluded();
     return  $self->item('', $_)  if (defined $self->{ITEM});
     $self->{NEEDSPACE} = 1;
     $self->output($_);
@@ -523,6 +550,7 @@ sub verbatim {
 sub textblock {
     my $self  = shift;
     my $text  = shift;
+    return  if $self->begun_excluded();
     return  $self->item('', $text)  if (defined $self->{ITEM});
     local($_) = $self->interpolate($text);
     s/\s*$/\n/;
