@@ -13,7 +13,7 @@
 package Pod::Select;
 
 require  5.003;    ## requires Perl version 5.002 or later
-$VERSION = 1.03;   ## Current version of this package
+$VERSION = 1.04;   ## Current version of this package
 
 #############################################################################
 
@@ -152,7 +152,7 @@ use vars qw(@ISA @EXPORT $VERSION);
 use strict;
 #use diagnostics;
 use Carp;
-use Pod::Parser 1.10;
+use Pod::Parser 1.04;
 
 @ISA = qw(Pod::Parser);
 @EXPORT = qw(&podselect);
@@ -176,6 +176,56 @@ reference to the object itself as an implicit first parameter.
 
 ##---------------------------------------------------------------------------
 
+## =begin _PRIVATE_
+## 
+## =head1 B<_init_headings()>
+## 
+## Initialize the current set of active section headings.
+## 
+## =cut
+## 
+## =end _PRIVATE_
+
+sub _init_headings {
+    my $self = shift;
+
+    ## Initialize current section heading titles if necessary
+    unless (defined $self->{_SECTION_HEADINGS}) {
+        $self->{_SECTION_HEADINGS} = [];
+        for (my $i = 0; $i < $MAX_HEADING_LEVEL; ++$i) {
+            $self->{_SECTION_HEADINGS}->[$i] = '';
+        }
+    }
+}
+
+##---------------------------------------------------------------------------
+
+=head1 B<curr_headings()>
+
+            ($head1, $head2, $head3, ...) = $parser->curr_headings();
+            $head1 = $parser->curr_headings(1);
+
+
+This method returns a list of the currently active section headings and
+subheadings in the document being parsed. The list of headings returned
+corresponds to the most recently parsed paragraph of the input.
+
+If an argument is given, it must correspond to the desired section
+heading number, in which case only the specified section heading is
+returned. If there is no current section heading at the specified
+level, then C<undef> is returned.
+
+=cut
+
+sub curr_headings {
+    my $self = shift;
+    $self->_init_headings()  unless (defined $self->{_SECTION_HEADINGS});
+    my @headings = @{ $self->{_SECTION_HEADINGS} };
+    return (@_ > 0  and  $_[0] =~ /^\d+$/) ? $headings[$_[0] - 1] : @headings;
+}
+
+##---------------------------------------------------------------------------
+
 =head1 B<select()>
 
             $parser->select($section_spec1,$section_spec2,...);
@@ -312,7 +362,7 @@ sub match_section {
     return  1  unless ((defined $selections) && (@{$selections} > 0));
 
     ## Default any unspecified sections to the current one
-    my @current_headings = @{ $self->{_SECTION_HEADINGS} };
+    my @current_headings = $self->curr_headings();
     for (my $i = 0; $i < $MAX_HEADING_LEVEL; ++$i) {
         (defined $headings[$i])  or  $headings[$i] = $current_headings[$i];
     }
@@ -363,13 +413,7 @@ sub is_selected {
     my ($self, $paragraph) = @_;
     local $_;
 
-    ## Initialize current section heading titles if necessary
-    unless (defined $self->{_SECTION_HEADINGS}) {
-        $self->{_SECTION_HEADINGS} = [];
-        for (my $i = 0; $i < $MAX_HEADING_LEVEL; ++$i) {
-            $self->{_SECTION_HEADINGS}->[$i] = '';
-        }
-    }
+    $self->_init_headings()  unless (defined $self->{_SECTION_HEADINGS});
 
     ## Keep track of current sections levels and headings
     $_ = $paragraph;
@@ -588,7 +632,7 @@ L<Pod::Parser>
 
 =head1 AUTHOR
 
-Brad Appleton E<lt>bradapp@enteract.mot.conE<gt>
+Brad Appleton E<lt>bradapp@enteract.mot.comE<gt>
 
 Based on code for B<pod2text> written by
 Tom Christiansen E<lt>tchrist@mox.perl.comE<gt>
