@@ -12,7 +12,7 @@
 
 package Pod::Usage;
 
-$VERSION = 1.03;   ## Current version of this package
+$VERSION = 1.04;   ## Current version of this package
 require  5.003;    ## requires Perl version 5.002 or later
 
 =head1 NAME
@@ -334,7 +334,7 @@ using something similar to the following:
 
 =head1 AUTHOR
 
-Brad Appleton E<lt>bradapp@enteract.mot.conE<gt>
+Brad Appleton E<lt>bradapp@enteract.mot.comE<gt>
 
 Based on code for B<Pod::Text::pod2text()> written by
 Tom Christiansen E<lt>tchrist@mox.perl.comE<gt>
@@ -355,7 +355,7 @@ use Carp;
 use Exporter;
 use Pod::PlainText;
 
-@ISA = qw(Pod::Text);
+@ISA = qw(Pod::PlainText);
 @EXPORT = qw(&pod2usage);
 
 ##---------------------------------------------------------------------------
